UtxosFilterInRequest

Enum UtxosFilterInRequest 

pub enum UtxosFilterInRequest {
    MinConfirmations(u32),
    min_confirmations(u32),
    Page(ByteBuf),
    page(ByteBuf),
}
A UtxosFilter enum that allows both upper and lowercase variants. Supporting both variants allows us to be compatible with the spec (lowercase) while not breaking current dapps that are using uppercase variants.

Variants



MinConfirmations(u32)



min_confirmations(u32)



Page(ByteBuf)



page(ByteBuf)